# CATNIP

**C**limate **A**nalysis **T**ools: **N**ow **I**n **P**ython

This library is a collection of routines to make frequently used climate data analysis
and visualisation tasks in Iris easier and quicker to write.

Complete documentation can be found at: [CATNIP Docs](https://metoffice.github.io/CATNIP/)


## Requirements
Please ensure you have the following dependencies installed:  

`iris` `numpy` `matplotlib` `six` `scipy`

## Usage
To get started make sure all the requirements are installed, then clone the repository
and set your Python environment to point to your copy, for example:

`git clone git@github.com:MetOffice/CATNIP.git`

`export PYTHONPATH=<path/to/CATNIP/lib>`


## Contact
For any suggestion, contribution and bug/error reporting, contact us at
**catnip@metoffice.gov.uk**

## License
[BSD-3 License](https://github.com/MetOffice/CATNIP/blob/master/LICENCE)
